import request from '@/utils/request'

// 查询题目分类列表
export function listCourseQuestionCategory(query) {
  return request({
    url: '/course/courseQuestionCategory/list',
    method: 'get',
    params: query
  })
}

// 查询题目分类详细
export function getCourseQuestionCategory(cateId) {
  return request({
    url: '/course/courseQuestionCategory/' + cateId,
    method: 'get'
  })
}

// 新增题目分类
export function addCourseQuestionCategory(data) {
  return request({
    url: '/course/courseQuestionCategory',
    method: 'post',
    data: data
  })
}

// 修改题目分类
export function updateCourseQuestionCategory(data) {
  return request({
    url: '/course/courseQuestionCategory',
    method: 'put',
    data: data
  })
}

// 删除题目分类
export function delCourseQuestionCategory(cateId) {
  return request({
    url: '/course/courseQuestionCategory/' + cateId,
    method: 'delete'
  })
}

// 导出题目分类
export function exportCourseQuestionCategory(query) {
  return request({
    url: '/course/courseQuestionCategory/export',
    method: 'get',
    params: query
  })
}
